@@ -14,14 +14,14 @@
 #
 import json
 import glob
-import logging
+from validations_libs.logger import getLogger
 import os
 import time
 from os.path import join
 
 from validations_libs import constants
 
-LOG = logging.getLogger(__name__ + ".validation_logs")
+LOG = getLogger(__name__ + ".validation_logs")
 
 
 class ValidationLog:
@@ -78,8 +78,8 @@ class ValidationLog:
                 self.uuid, _name = self.name.split('_', 1)
                 self.validation_id, self.datetime = _name.rsplit('_', 1)
             except ValueError:
-                logging.warning('Wrong log file format, it should be formed '
-                                'such as {uuid}_{validation-id}_{timestamp}')
+                LOG.warning('Wrong log file format, it should be formed '
+                            'such as {uuid}_{validation-id}_{timestamp}')
 
     def _get_content(self):
         try:
@@ -299,8 +299,14 @@ class ValidationLog:
                 for h in v_output['task']['hosts']:
                     msg = v_output['task']['hosts'][h].get('msg',
                                                            'Unknown')
-                    msg = msg[:50] + '\n' + msg[50:]
-                    reason.append('{}: {}'.format(h, msg))
+                    if isinstance(msg, list):
+                        msg = ''.join(msg)
+                    try:
+                        msg = msg[:50] + '\n' + msg[50:]
+                        reason.append('{}: {}'.format(h, msg))
+                    except TypeError:
+                        LOG.warning('Wrong failure message type. skipping...')
+                        reason.append('Unknown')
             if not self.content['validation_output']:
                 if self.get_unreachable_hosts:
                     reason.append('Unreachable')
